@@ -13,12 +13,16 @@ use namespace::clean;
 
 # ABSTRACT: communicates with DPD API
 
-our $VERSION = 'v0.0002';
+our $VERSION = 'v0.0004';
 
  
 =head1 NAME
 
-WebService::DPD::API
+WebService::DPD::API 
+
+=head1 WARNING
+
+This module is depreciated. It will be replaced by WebService::GeoPost::DPD, this is allow expanding the namespace to accomodate other API services provided by GeoPost.
 
 =head1 SYNOPSIS
 
@@ -51,7 +55,7 @@ has password => (
 );
 
 has url => ( is => 'ro',
-			 default => 'https://api.dpd.co.uk'
+			 default => sub {'https://api.dpd.co.uk'},
 			);
 
 has host => ( is => 'ro',
@@ -73,7 +77,7 @@ has geoSession => (
 
 has geoClient => (
 	is => 'ro',
-	default => 'thirdparty/pryanet',
+	default => sub {'thirdparty/pryanet'},
 );
 
 has debug => (
@@ -303,7 +307,7 @@ sub get_labels
 
 =head1 FUTURE METHODS
 
-These methods are implemented as documented in the DPD API specification.  Although at the time of writing their functionality has not been publically implemented within the API.
+These methods are implemented as documented in the DPD API specification.  Although at the time of writing their functionality has not been publicly implemented within the API.
 
 =cut 
 
@@ -544,7 +548,7 @@ sub get_manifest_by_id
 
 =head2 _to_query_params
 
-Recursiverly converts hash of hashes into query string for http request
+Recursively converts hash of hashes into query string for http request
 
 =cut
 sub _to_query_params
@@ -687,6 +691,7 @@ None known.
 	Carp
 	Moo
 	LWP::UserAgent
+	LWP::Protocol::https
 	HTTP::Request::Common
 	URI::Escape
 	Data::Dumper
